@@ -2,7 +2,7 @@
    The VisBox class for the molecular dynamics trajectory viewer
 
    Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011,
-   2012 Oleksandr Yermolenko <oleksandr.yermolenko@gmail.com>
+   2012, 2013 Oleksandr Yermolenko <oleksandr.yermolenko@gmail.com>
 
    This file is part of MDTK, the Molecular Dynamics Toolkit.
 
@@ -159,6 +159,22 @@ VisBox::loadDataFromFiles(std::string base_state_filename,
   size_range(100, 100, 5000, 5000, 3*4, 3*4, 1);
 }
 
+void
+VisBox::loadDataFromMDLoopStates(const std::vector<std::string>& mdloopStates)
+{
+  MDTrajectory_read_from_mdloop_states(mdt, mdloopStates);
+}
+
+void
+VisBox::loadDataFromFilesOfNewFileFormat(
+  const std::vector<std::string>& states,
+  const std::vector<std::string>& xvas,
+  bool loadPartialSnapshots)
+{
+  *ml_ = MDTrajectory_read_ng(mdt,states,xvas,loadPartialSnapshots);
+  size_range(100, 100, 5000, 5000, 3*4, 3*4, 1);
+}
+
 void
 VisBox::loadDataFromSimulation(bool quench)
 {
@@ -357,17 +373,24 @@ VisBox::drawObjects()
     listBarrier();
     glEnable(GL_LIGHTING);
   }
-  if (showBath)
+  if (ml_->thermalBathGeomType != mdtk::SimLoop::TB_GEOM_NONE)
   {
-    glDisable(GL_LIGHTING);
-    listThermalBath();
-    glEnable(GL_LIGHTING);
-  }
-  if (showBathSketch)
-  {
-    glDisable(GL_LIGHTING);
-    listThermalBathSketch();
-    glEnable(GL_LIGHTING);
+    if (showBath)
+    {
+      glDisable(GL_LIGHTING);
+      if (ml_->thermalBathGeomType == mdtk::SimLoop::TB_GEOM_BOX)
+        listThermalBathGeomBox();
+      glEnable(GL_LIGHTING);
+    }
+    if (showBathSketch)
+    {
+      glDisable(GL_LIGHTING);
+      if (ml_->thermalBathGeomType == mdtk::SimLoop::TB_GEOM_BOX)
+        listThermalBathGeomBoxSketch();
+      if (ml_->thermalBathGeomType == mdtk::SimLoop::TB_GEOM_SPHERE)
+        listThermalBathGeomSphereSketch();
+      glEnable(GL_LIGHTING);
+    }
   }
   if (showCustom1)
   {
@@ -411,16 +434,16 @@ VisBox::listBarrier()
 }
 
 void
-VisBox::listThermalBath()
+VisBox::listThermalBathGeomBox()
 {
   Float tb[3][2];
 
-  tb[0][0] = ml_->thermalBath.dBoundary;
-  tb[0][1] = -ml_->thermalBath.dBoundary+ml_->atoms.PBC().x;
-  tb[1][0] = ml_->thermalBath.dBoundary;
-  tb[1][1] = -ml_->thermalBath.dBoundary+ml_->atoms.PBC().y;
-  tb[2][0] = ml_->thermalBath.zMinOfFreeZone;
-  tb[2][1] = ml_->thermalBath.zMin;
+  tb[0][0] = ml_->thermalBathGeomBox.dBoundary;
+  tb[0][1] = -ml_->thermalBathGeomBox.dBoundary+ml_->atoms.PBC().x;
+  tb[1][0] = ml_->thermalBathGeomBox.dBoundary;
+  tb[1][1] = -ml_->thermalBathGeomBox.dBoundary+ml_->atoms.PBC().y;
+  tb[2][0] = ml_->thermalBathGeomBox.zMinOfFreeZone;
+  tb[2][1] = ml_->thermalBathGeomBox.zMin;
 
   Float cb[3][2] = {{0,0},{0,0},{0,0}};
   cb[0][1] = ml_->atoms.PBC().x;
@@ -440,7 +463,7 @@ VisBox::listThermalBath()
   glVertex3d(tb[0][1],tb[1][0],tb[2][1]);
   glEnd();
 
-  if (ml_->thermalBath.dBoundary != 0.0)
+  if (ml_->thermalBathGeomBox.dBoundary != 0.0)
   {
     int vi = 0, vj;
     do
@@ -468,16 +491,16 @@ VisBox::listThermalBath()
 }
 
 void
-VisBox::listThermalBathSketch()
+VisBox::listThermalBathGeomBoxSketch()
 {
   Float tb[3][2];
 
-  tb[0][0] = ml_->thermalBath.dBoundary;
-  tb[0][1] = -ml_->thermalBath.dBoundary+ml_->atoms.PBC().x;
-  tb[1][0] = ml_->thermalBath.dBoundary;
-  tb[1][1] = -ml_->thermalBath.dBoundary+ml_->atoms.PBC().y;
-  tb[2][0] = ml_->thermalBath.zMinOfFreeZone;
-  tb[2][1] = ml_->thermalBath.zMin;
+  tb[0][0] = ml_->thermalBathGeomBox.dBoundary;
+  tb[0][1] = -ml_->thermalBathGeomBox.dBoundary+ml_->atoms.PBC().x;
+  tb[1][0] = ml_->thermalBathGeomBox.dBoundary;
+  tb[1][1] = -ml_->thermalBathGeomBox.dBoundary+ml_->atoms.PBC().y;
+  tb[2][0] = ml_->thermalBathGeomBox.zMinOfFreeZone;
+  tb[2][1] = ml_->thermalBathGeomBox.zMin;
 
   Float cb[3][2] = {{0,0},{0,0},{0,0}};
   cb[0][1] = ml_->atoms.PBC().x;
@@ -504,7 +527,7 @@ VisBox::listThermalBathSketch()
   glVertex3d(cb[0][1]/2.0+cb[0][0],cb[1][1],cb[2][1]);
   glEnd();
 
-  if (ml_->thermalBath.dBoundary != 0.0)
+  if (ml_->thermalBathGeomBox.dBoundary != 0.0)
   {
     glBegin(GL_QUADS);
     glVertex3d(cb[0][0],cb[1][1]/2.0+cb[1][0],cb[2][0]);
@@ -536,6 +559,58 @@ VisBox::listThermalBathSketch()
   glPopMatrix();  
 }
 
+void
+VisBox::listThermalBathGeomSphereSketch()
+{
+  Float tb_sphere_radius = ml_->thermalBathGeomSphere.radius;
+  Vector3D tb_sphere_center = ml_->thermalBathGeomSphere.center;
+  Float tb_sphere_zMinOfFreeZone = ml_->thermalBathGeomSphere.zMinOfFreeZone;
+
+  Float z_max = tb_sphere_radius*3;
+  Float y = tb_sphere_center.y;
+
+  std::vector<Float> x_values;
+  std::vector<Float> z_min_values;
+  Float x_half_range = tb_sphere_radius*3;
+  for(Float x = -x_half_range; x < +x_half_range; x += 0.1*Ao)
+  {
+    Float z_min = tb_sphere_zMinOfFreeZone;
+    if ((Vector3D(x,y,z_min) - tb_sphere_center).module() < tb_sphere_radius)
+    {
+      z_min = tb_sphere_center.z +
+        sqrt(SQR(tb_sphere_radius) - SQR(x - tb_sphere_center.x));
+    }
+
+    x_values.push_back(x);
+    z_min_values.push_back(z_min);
+  }
+
+  for(size_t i = 0; i < x_values.size()-1; ++i)
+  {
+    GLubyte tbc[4]={0,227,127,127};
+
+    glColor4ubv(tbc);
+
+    glPushMatrix();
+
+    glBegin(GL_QUADS);
+    glVertex3d(x_values[i+1],y,z_min_values[i+1]);
+    glVertex3d(x_values[i+1],y,z_max);
+    glVertex3d(x_values[i],y,z_max);
+    glVertex3d(x_values[i],y,z_min_values[i+1]);
+    glEnd();
+
+    glBegin(GL_QUADS);
+    glVertex3d(y,x_values[i+1],z_min_values[i+1]);
+    glVertex3d(y,x_values[i+1],z_max);
+    glVertex3d(y,x_values[i],z_max);
+    glVertex3d(y,x_values[i],z_min_values[i+1]);
+    glEnd();
+
+    glPopMatrix();
+  }
+}
+
 void
 VisBox::listAxes()
 {
@@ -804,41 +879,102 @@ VisBox::listCustom1()
   for(size_t i = 0; i < ml_->atoms.size(); i++)
   {
     mdtk::Atom& a = ml_->atoms[i];
-    if (a.ID == Cu_EL) cluster.push_back(a);
+    if (a.hasTag(ATOMTAG_CLUSTER)) cluster.push_back(a);
   }
 
   Float halo = 1.3*Ao;
   Float depth = 0.0;
   {
-    halo = 5.0*Ao;
-    glColor4ub(0,0,255,255);
     depth = -15.0*Ao;
 
+//    halo = 26.6285*Ao;
+    halo = 30.0*Ao;
+    glColor4ub(127,127,127,255);
+
     for(size_t i = 0; i < cluster.size(); i++)
     {
       glPushMatrix();
       glTranslated(cluster[i].coords.x,cluster[i].coords.y,depth);
       glScaled(halo,halo,halo);
-      glCallList(hqMode?lstBallHQ:lstBall);
-      glPopMatrix();  
+//      glCallList(hqMode?lstBallHQ:lstBall);
+      glCallList(lstBallHQ);
+      glPopMatrix();
     }
+  }
+
+  {
+    depth -= halo;
+
+    halo = 20.0*Ao;
+    glColor4ub(0,127,0,255);
+
+    for(size_t i = 0; i < cluster.size(); i++)
+    {
+      glPushMatrix();
+      glTranslated(cluster[i].coords.x,cluster[i].coords.y,depth);
+      glScaled(halo,halo,halo);
+//      glCallList(hqMode?lstBallHQ:lstBall);
+      glCallList(lstBallHQ);
+      glPopMatrix();
+    }
+  }
+
+  {
+    depth -= halo;
+
+    halo = 10.0*Ao;
+    glColor4ub(127,0,0,255);
+
+    for(size_t i = 0; i < cluster.size(); i++)
+    {
+      glPushMatrix();
+      glTranslated(cluster[i].coords.x,cluster[i].coords.y,depth);
+      glScaled(halo,halo,halo);
+//      glCallList(hqMode?lstBallHQ:lstBall);
+      glCallList(lstBallHQ);
+      glPopMatrix();
+    }
+  }
+
+  {
+    depth -= halo;
+
+    halo = 5.5*Ao;
+    glColor4ub(0,0,255,255);
+
+    for(size_t i = 0; i < cluster.size(); i++)
+    {
+      glPushMatrix();
+      glTranslated(cluster[i].coords.x,cluster[i].coords.y,depth);
+      glScaled(halo,halo,halo);
+//      glCallList(hqMode?lstBallHQ:lstBall);
+      glCallList(lstBallHQ);
+      glPopMatrix();
+    }
+  }
+
+  {
+    depth -= halo;
 
     glColor4ub(0,255,0,255);
     halo = 1.3*Ao;
-    depth = -22.0*Ao;
 
     for(size_t i = 0; i < cluster.size(); i++)
     {
       glPushMatrix();
       glTranslated(cluster[i].coords.x,cluster[i].coords.y,depth);
       glScaled(halo,halo,halo);
-      glCallList(hqMode?lstBallHQ:lstBall);
-      glPopMatrix();  
+//      glCallList(hqMode?lstBallHQ:lstBall);
+      glCallList(lstBallHQ);
+      glPopMatrix();
     }
+  }
+
+  {
+    depth -= halo;
 
     glColor4ub(255,255,0,255);
     halo = 0.3*Ao;
-    depth = -24.0*Ao;
 
     for(size_t i = 0; i < cluster.size(); i++)
     {
@@ -1146,18 +1282,50 @@ VisBox::saveToMDE(char* filename)
   fo.close();
 }  
 
-void
-VisBox::saveState(char* filename)
+mdtk::Vector3D getPosition()
 {
-  if (yaatk::exists(filename))
+  GLdouble m[16];
+  glGetDoublev(GL_MODELVIEW_MATRIX,m);
+  return Vector3D(m[3*4+0],m[3*4+1],m[3*4+2]);
+}
+
+void
+VisBox::saveState(std::string id, bool discardRotation)
+{
+  if (yaatk::exists(id) || yaatk::exists(id + ".r"))
   {
     if (fl_choice("File exists. Do you really want to overwrite it?","No","Yes",NULL)!=1)
       return;
   }
 
-  yaatk::text_ofstream fo(filename);
+  AtomsArray backup;
+
+  if (!discardRotation)
+  {
+    backup = ml_->atoms;
+
+    glMatrixMode(GL_MODELVIEW);
+
+    for(size_t i = 0; i < R.size();i++)
+    {
+      glPushMatrix();
+      glTranslated(R[i].coords.x,R[i].coords.y,R[i].coords.z);
+      ml_->atoms[i].coords = getPosition();
+      glPopMatrix();
+    }
+  }
+
+  yaatk::text_ofstream fo("mdloop.compat-" + id);
   ml_->saveToStream(fo);
   fo.close();
+
+  mdtk::SimLoopSaver mds(*ml_);
+  mds.write(id);
+
+  if (!discardRotation)
+  {
+    ml_->atoms = backup;
+  }
 }
 
 #ifdef MDTRAJVIEW_PNG
