@@ -3,7 +3,7 @@
    (header file)
 
    Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011,
-   2012 Oleksandr Yermolenko <oleksandr.yermolenko@gmail.com>
+   2012, 2013 Oleksandr Yermolenko <oleksandr.yermolenko@gmail.com>
 
    This file is part of MDTK, the Molecular Dynamics Toolkit.
 
@@ -114,8 +114,10 @@ private:
   void listVertexes();
   void listAxes();
   void listBarrier();
-  void listThermalBath();
-  void listThermalBathSketch();
+  void listThermalBathGeomBox();
+  void listThermalBathGeomBoxSketch();
+  void listThermalBathGeomSphere();
+  void listThermalBathGeomSphereSketch();
   void listCTree();
   void listBonds();
   void listCustom1();
@@ -147,6 +149,11 @@ public:
   void loadDataFromFiles(std::string base_state_filename,
                          const std::vector<std::string>& xvas,
                          bool loadPartialSnapshots = false);
+  void loadDataFromMDLoopStates(const std::vector<std::string>& mdloopStates);
+  void loadDataFromFilesOfNewFileFormat(
+    const std::vector<std::string>& states,
+    const std::vector<std::string>& xvas,
+    bool loadPartialSnapshots = false);
   void loadDataFromSimulation(bool quench);
   virtual ~VisBox(){delete ml_;};
 
@@ -156,7 +163,7 @@ public:
   void saveImageToFile(char* filename);
   void saveTiledImageToFile(char* filename);
   void saveToMDE(char* filename);
-  void saveState(char* filename);
+  void saveState(std::string id, bool discardRotation = false);
 
   static void window_cb(Fl_Widget *, void *);
 
