@@ -1,8 +1,8 @@
 /*
    The molecular dynamics simulation loop class.
 
-   Copyright (C) 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012
-   Oleksandr Yermolenko <oleksandr.yermolenko@gmail.com>
+   Copyright (C) 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012,
+   2013 Oleksandr Yermolenko <oleksandr.yermolenko@gmail.com>
 
    This file is part of MDTK, the Molecular Dynamics Toolkit.
 
@@ -22,6 +22,7 @@
 
 #include "Exception.hpp"
 #include "SimLoop.hpp"
+#include "SimLoopSaver.hpp"
 #include <fstream>
 #include "release_info.hpp"
 
@@ -50,8 +51,11 @@ SimLoop::SimLoop()
     dt(1e-20),
     dt_prev(1e-20),
     iteration(0),
-    iterationFlushStateInterval(1000),
-    thermalBath(),
+    iterationFlushStateInterval(1000000),
+    thermalBathCommon(),
+    thermalBathGeomBox(),
+    thermalBathGeomSphere(),
+    thermalBathGeomType(TB_GEOM_NONE),
     initNLafterLoading(true),
     allowPartialLoading(false),
     fpot(),
@@ -76,7 +80,10 @@ SimLoop::SimLoop(const SimLoop &c)
     dt_prev(1e-20), // check this!
     iteration(c.iteration),
     iterationFlushStateInterval(c.iterationFlushStateInterval),
-    thermalBath(c.thermalBath),
+    thermalBathCommon(c.thermalBathCommon),
+    thermalBathGeomBox(c.thermalBathGeomBox),
+    thermalBathGeomSphere(c.thermalBathGeomSphere),
+    thermalBathGeomType(c.thermalBathGeomType),
     initNLafterLoading(true),
     allowPartialLoading(false),
     fpot(),
@@ -107,7 +114,10 @@ SimLoop::operator =(const SimLoop &c)
   dt_prev = 1e-20; // check this!
   iteration = c.iteration;
   iterationFlushStateInterval = c.iterationFlushStateInterval;
-  thermalBath = c.thermalBath;
+  thermalBathCommon = c.thermalBathCommon;
+  thermalBathGeomBox = c.thermalBathGeomBox;
+  thermalBathGeomSphere = c.thermalBathGeomSphere;
+  thermalBathGeomType = c.thermalBathGeomType;
   initNLafterLoading = true;
   allowPartialLoading = false;
 //  fpot();
@@ -134,21 +144,42 @@ SimLoop::execute()
   try
   {
     fpot.diagnose();
-    PTRACE(atoms.front().PBCEnabled());
-    PTRACE(atoms.front().lateralPBCEnabled());
-    PTRACE(atoms.back().PBCEnabled());
-    PTRACE(atoms.back().lateralPBCEnabled());
-    PTRACE(atoms.front().PBC/Ao);
-    PTRACE(atoms.back().PBC/Ao);
-    PTRACE(thermalBath.zMin/Ao);
-    PTRACE(thermalBath.dBoundary/Ao);
-    PTRACE(thermalBath.zMinOfFreeZone/Ao);
-    PTRACE(thermalBath.To/K);
+    TRACE(atoms.front().ID);
+    TRACE(atoms.front().PBCEnabled());
+    TRACE(atoms.front().lateralPBCEnabled());
+    TRACE(atoms.front().PBC/Ao);
+    TRACE(atoms.front().apply_ThermalBath);
+    TRACE(atoms.back().ID);
+    TRACE(atoms.back().PBCEnabled());
+    TRACE(atoms.back().lateralPBCEnabled());
+    TRACE(atoms.back().PBC/Ao);
+    TRACE(atoms.back().apply_ThermalBath);
+    TRACE((atoms.rbegin()+1)->ID);
+    TRACE((atoms.rbegin()+1)->PBCEnabled());
+    TRACE((atoms.rbegin()+1)->lateralPBCEnabled());
+    TRACE((atoms.rbegin()+1)->PBC/Ao);
+    TRACE((atoms.rbegin()+1)->apply_ThermalBath);
+    TRACE(thermalBathGeomType == TB_GEOM_NONE);
+    TRACE(thermalBathGeomType == TB_GEOM_UNIVERSE);
+    TRACE(thermalBathGeomType == TB_GEOM_BOX);
+    TRACE(thermalBathGeomType == TB_GEOM_SPHERE);
+    TRACE(thermalBathCommon.gamma);
+    TRACE(thermalBathCommon.To/K);
+    TRACE(thermalBathGeomBox.zMin/Ao);
+    TRACE(thermalBathGeomBox.dBoundary/Ao);
+    TRACE(thermalBathGeomBox.zMinOfFreeZone/Ao);
+    TRACE(thermalBathGeomSphere.center/Ao);
+    TRACE(thermalBathGeomSphere.radius/Ao);
+    TRACE(thermalBathGeomSphere.zMinOfFreeZone/Ao);
     return executeMain();
   }
   catch (Exception& e)
   {
     std::cerr << "Caught mdtk Exception: " << e.what() << std::endl;
+    {
+      yaatk::text_ofstream fo2("completed.error");
+      fo2.close();
+    }
     std::cerr << "Flushing state.....";
     writestate();
     {
@@ -181,7 +212,7 @@ int SimLoop::executeDryRun()
   atoms.prepareForSimulatation();
 //  REQUIRE(atoms.checkMIC(fpot.getRcutoff()*2.0));
 
-  PTRACE(initNLafterLoading);
+  TRACE(initNLafterLoading);
   if (initNLafterLoading)
   {
     fpot.NL_init(atoms);
@@ -229,7 +260,7 @@ SimLoop::executeMain()
       cout << "dt : " << dt << endl;
     }
 
-    if (iteration%iterationFlushStateInterval == 0/* && iteration != 0*/)
+    if (iteration%iterationFlushStateInterval == 0 && iteration != 0)
     {
       if (verboseTrace) cout << "Writing state ... " ;
       writestate();
@@ -237,7 +268,9 @@ SimLoop::executeMain()
     };
 
 
-    if (simTime == 0.0 || int(simTime/simTimeSaveTrajInterval) != int((simTime - dt_prev)/simTimeSaveTrajInterval))
+    if(iteration == 0 ||
+       simTime == 0.0 ||
+       int(simTime/simTimeSaveTrajInterval) != int((simTime - dt_prev)/simTimeSaveTrajInterval))
     {
       if (verboseTrace) cout << "Writing trajectory ... " ;
       writetrajXVA();
@@ -247,7 +280,7 @@ SimLoop::executeMain()
     Float actualThermalBathTemp = actualTemperatureOfThermalBath();
     {
       Float Tb = actualThermalBathTemp;
-      PTRACE(Tb);
+      TRACE(Tb);
     }
 
     if (check.checkForce)
@@ -316,16 +349,16 @@ SimLoop::executeMain()
 
       Vector3D  vdt2 = atom.V + atom.an*dt/2.0; // eq 2
 
-      if (isWithinThermalBath(atom) && atom.apply_ThermalBath)
+      if (thermalBathShouldBeApplied(atom))
       {
 //        Float T = check.temperatureCur;
         Float T = actualThermalBathTemp;
-        Float To_by_T = (fabs(T)<1e-5)?0:(thermalBath.To/T);
+        Float To_by_T = (fabs(T)<1e-5)?0:(thermalBathCommon.To/T);
         Float max_To_by_T = 5.0;
         if (To_by_T < -max_To_by_T) To_by_T = -max_To_by_T;
         if (To_by_T > +max_To_by_T) To_by_T = +max_To_by_T;
 
-        Vector3D dforce = -atom.V*atom.M*thermalBath.gamma*(1.0-sqrt(To_by_T));
+        Vector3D dforce = -atom.V*atom.M*thermalBathCommon.gamma*(1.0-sqrt(To_by_T));
 
         // try to account energy transfered to thermalbath
         // only required to perform energy conservation check
@@ -360,12 +393,7 @@ SimLoop::executeMain()
 
       Float v = atom.V.module();
       if (v > v_max &&
-          fpot.hasNB(atom) &&
-          atom.coords.z > -20.0*Ao &&
-          abs(atom.PBC_count.x) < 2 &&
-          abs(atom.PBC_count.y) < 2 &&
-          abs(atom.PBC_count.z) < 2 &&
-          atom.coords.module() < 500.0*Ao
+          fpot.hasNeighbors(atom)
          )
         v_max = v;
     }
@@ -394,7 +422,7 @@ SimLoop::executeMain()
         if (verboseTrace)
         {
           Float ffmod = check.netForce.module();
-          PTRACE(ffmod);
+          TRACE(ffmod);
         }
         cerr << "FullForce != 0" << endl << flush;
         cout << "FullForce != 0" << endl << flush;
@@ -424,6 +452,7 @@ SimLoop::executeMain()
 
     cout << "--------------------------------------------------------- " << endl;
   }
+  if (0)
   {
     if (verboseTrace) cout << "Writing trajectory ... ";
     writetrajXVA();
@@ -455,9 +484,9 @@ SimLoop::energy()
     Float Ek = energyKinCur/mdtk::eV;
     Float Et = (energyPotCur+energyKinCur)/mdtk::eV;
 
-    PTRACE(Ep);
-    PTRACE(Ek);
-    PTRACE(Et);
+    TRACE(Ep);
+    TRACE(Ek);
+    TRACE(Et);
   }
 
   return energyPotCur+energyKinCur;
@@ -489,7 +518,7 @@ SimLoop::temperature()
 {
 //  Float T = energyKin()/(3.0/2.0*kb*atoms_.size());
   Float T = temperatureWithoutFixed();
-  PTRACE(T);
+  TRACE(T);
   return T;
 }
 
@@ -503,7 +532,7 @@ SimLoop::actualTemperatureOfThermalBath()
   {
     Atom& atom = atoms[j];
     if (atom.isFixed()) continue;
-    if (isWithinThermalBath(atom) && atom.apply_ThermalBath)
+    if (thermalBathShouldBeApplied(atom))
     {
       energyKinCur += atom.M*SQR(atom.V.module())/2.0;
       atoms_accounted++;
@@ -555,7 +584,8 @@ SimLoop::loadFromStream(istream& is, YAATK_FSTREAM_MODE smode)
   YAATK_FSTREAM_READ(is,iteration,smode);
   YAATK_FSTREAM_READ(is,iterationFlushStateInterval,smode);
 
-  thermalBath.loadFromStream(is,smode);
+  legacyThermalBathStruct.loadFromStream(is,smode);
+  updateThermalBathFromLegacyStruct();
 
 //  fpot.LoadFromStream(is,smode);
 
@@ -589,7 +619,7 @@ SimLoop::saveToStream(ostream& os, YAATK_FSTREAM_MODE smode)
   YAATK_FSTREAM_WRITE(os,iteration,smode);
   YAATK_FSTREAM_WRITE(os,iterationFlushStateInterval,smode);
 
-  thermalBath.saveToStream(os,smode);
+  legacyThermalBathStruct.saveToStream(os,smode);
 
 //  fpot.SaveToStream(os,smode);
 
@@ -1043,12 +1073,17 @@ SimLoop::writestate()
 {
   if (preventFileOutput) return;
 
+  mdtk::SimLoopSaver mds(*this);
+  mds.write();
+
+  if (0)
   {
     yaatk::binary_ofstream fo1("simloop.conf.bak");
     saveToStream(fo1,YAATK_FSTREAM_BIN);
     fo1.close();
   }
 
+  if (0)
   {
     yaatk::binary_ofstream fo1("simloop.conf");
     saveToStream(fo1,YAATK_FSTREAM_BIN);
@@ -1141,7 +1176,7 @@ SimLoop::saveToMDE(std::ostream& fo)
 
   REQUIRE(atoms.size() > 0);
   fo << atoms.PBC() << std::endl;
-  thermalBath.saveToStream(fo,YAATK_FSTREAM_TEXT);
+  legacyThermalBathStruct.saveToStream(fo,YAATK_FSTREAM_TEXT);
 }
 
 void
@@ -1193,7 +1228,8 @@ SimLoop::loadFromMDE(std::istream& fi)
   Vector3D PBC;
   fi >> PBC;
   setPBC(PBC);
-  thermalBath.loadFromStream(fi,YAATK_FSTREAM_TEXT);
+  legacyThermalBathStruct.loadFromStream(fi,YAATK_FSTREAM_TEXT);
+  updateThermalBathFromLegacyStruct();
 
   executeDryRun();
 }
@@ -1203,11 +1239,14 @@ SimLoop::heatUpEveryAtom(Float upEnergy, gsl_rng* rng)
 {
   for(size_t i = 0; i < atoms.size(); i++)
   {
-    Vector3D vn(gsl_rng_uniform(rng)-1.0,gsl_rng_uniform(rng)-1.0,gsl_rng_uniform(rng)-1.0);
-    vn.normalize();
+    if (atoms[i].isFixed()) continue;
+
+    Vector3D vn;
+    gsl_ran_dir_3d(rng, &vn.x, &vn.y, &vn.z);
 
     atoms[i].V = vn*sqrt(2.0*upEnergy/atoms[i].M);
   }
+  atoms.removeMomentum();
 }
 
 void
@@ -1215,8 +1254,10 @@ SimLoop::displaceEveryAtom(Float dist, gsl_rng* rng)
 {
   for(size_t i = 0; i < atoms.size(); i++)
   {
-    Vector3D vn(gsl_rng_uniform(rng)-1.0,gsl_rng_uniform(rng)-1.0,gsl_rng_uniform(rng)-1.0);
-    vn.normalize();
+    if (atoms[i].isFixed()) continue;
+
+    Vector3D vn;
+    gsl_ran_dir_3d(rng, &vn.x, &vn.y, &vn.z);
 
     TRACE(vn*dist/Ao);
     TRACE((vn*dist).module()/Ao);
@@ -1269,13 +1310,13 @@ ThermalBath::disableGlobally()
 }
 */
 
-SimLoop::ThermalBath::ThermalBath(Float zMin_, Float dBoundary_, Float zMinOfFreeZone_)
+SimLoop::LegacyThermalBathStruct::LegacyThermalBathStruct(Float zMin_, Float dBoundary_, Float zMinOfFreeZone_)
   :zMin(zMin_), dBoundary(dBoundary_), zMinOfFreeZone(zMinOfFreeZone_), To(0.0), gamma(1.0e13)
 {
 }
 
 void
-SimLoop::ThermalBath::saveToStream(std::ostream& os, YAATK_FSTREAM_MODE smode)
+SimLoop::LegacyThermalBathStruct::saveToStream(std::ostream& os, YAATK_FSTREAM_MODE smode)
 {
   YAATK_FSTREAM_WRITE(os,zMin,smode);
   YAATK_FSTREAM_WRITE(os,dBoundary,smode);
@@ -1285,7 +1326,7 @@ SimLoop::ThermalBath::saveToStream(std::ostream& os, YAATK_FSTREAM_MODE smode)
 }
 
 void
-SimLoop::ThermalBath::loadFromStream(std::istream& is, YAATK_FSTREAM_MODE smode)
+SimLoop::LegacyThermalBathStruct::loadFromStream(std::istream& is, YAATK_FSTREAM_MODE smode)
 {
   YAATK_FSTREAM_READ(is,zMin,smode);
   YAATK_FSTREAM_READ(is,dBoundary,smode);
@@ -1295,16 +1336,16 @@ SimLoop::ThermalBath::loadFromStream(std::istream& is, YAATK_FSTREAM_MODE smode)
 }
 
 bool
-SimLoop::isWithinThermalBath(const Atom& a)
+SimLoop::LegacyThermalBathStruct::isInsideThermalBath(const Atom& a)
 {
-  return (a.coords.z > thermalBath.zMin) ||
+  return (a.coords.z > zMin) ||
     (a.lateralPBCEnabled() &&
      (
-       (a.coords.x < 0.0 + thermalBath.dBoundary) ||
-       (a.coords.x > a.PBC.x - thermalBath.dBoundary) ||
-       (a.coords.y < 0.0 + thermalBath.dBoundary) ||
-       (a.coords.y > a.PBC.y - thermalBath.dBoundary)
-       ) && a.coords.z > thermalBath.zMinOfFreeZone
+       (a.coords.x < 0.0 + dBoundary) ||
+       (a.coords.x > a.PBC.x - dBoundary) ||
+       (a.coords.y < 0.0 + dBoundary) ||
+       (a.coords.y > a.PBC.y - dBoundary)
+       ) && a.coords.z > zMinOfFreeZone
       );
 }
 
