@@ -1,7 +1,7 @@
 /*
    Some configuration constants for MDTK (header file).
 
-   Copyright (C) 2004, 2005, 2009 Oleksandr Yermolenko
+   Copyright (C) 2004, 2005, 2009, 2013 Oleksandr Yermolenko
    <oleksandr.yermolenko@gmail.com>
 
    This file is part of MDTK, the Molecular Dynamics Toolkit.
@@ -36,12 +36,25 @@ namespace mdtk
 {
 
 typedef double Float;
-typedef size_t Index;
 
 extern const int FLOAT_PRECISION;
 
 extern bool verboseTrace;
 
+struct VerboseOutput
+{
+  bool prevVerboseOutputState;
+  VerboseOutput(bool newState)
+  :prevVerboseOutputState(verboseTrace)
+    {
+      verboseTrace = newState;
+    }
+  ~VerboseOutput()
+    {
+      verboseTrace = prevVerboseOutputState;
+    }
+};
+
 }
 
 #endif
