@@ -4,8 +4,8 @@
    See [S.J. Stuart, A.B. Tutein and J.A. Harrison,
    J. Chem. Phys. 112, 6472 (2000)]
 
-   Copyright (C) 2005, 2006, 2007, 2008, 2009, 2011, 2012 Oleksandr
-   Yermolenko <oleksandr.yermolenko@gmail.com>
+   Copyright (C) 2005, 2006, 2007, 2008, 2009, 2011, 2012, 2013
+   Oleksandr Yermolenko <oleksandr.yermolenko@gmail.com>
 
    This file is part of MDTK, the Molecular Dynamics Toolkit.
 
@@ -49,7 +49,7 @@ ETors::operator()(AtomsArray& gl)
 
           AtomsPair ij(atom_i,atom_j,R(0,atom_i,atom_j),R(1,atom_i,atom_j));
 
-          for(Index k = 0; k < nli.size(); k++)
+          for(size_t k = 0; k < nli.size(); k++)
           {
             Atom &atom_k = *(nli[k]);
             if (&atom_k != &atom_i && &atom_k != &atom_j)
@@ -57,7 +57,7 @@ ETors::operator()(AtomsArray& gl)
               if (!probablyAreNeighbours(atom_i,atom_k)) continue;
               AtomsPair ki(atom_k,atom_i,R(0,atom_k,atom_i),R(1,atom_k,atom_i));
               AtomRefsContainer& nlj = NL(atom_j);
-              for(Index l = 0; l < nlj.size(); l++)
+              for(size_t l = 0; l < nlj.size(); l++)
               {
                 Atom &atom_l = *(nlj[l]);
                 if (&atom_l != &atom_i && &atom_l != &atom_j &&  &atom_l != &atom_k )
@@ -124,12 +124,12 @@ ETors::ETors():
 void
 ETors::setupPotential()
 {
-  PTRACE("Setup ETORS");
-
   zetaCC_[C][C] = 0.3079*eV;
   zetaCC_[H][H] = 0.1250*eV;
   zetaCC_[C][H] = 0.1787*eV;
     zetaCC_[H][C] = zetaCC_[C][H];
+
+  PRINT("AIREBO::ETors interatomic potential configured.\n");
 }
 
 }
