@@ -3,7 +3,7 @@
    hydrocarbons.
    See [D.W. Brenner, Phys. Rev. B 42, 9458 (1990)]
 
-   Copyright (C) 2004, 2005, 2006, 2007, 2009, 2012 Oleksandr
+   Copyright (C) 2004, 2005, 2006, 2007, 2009, 2012, 2013 Oleksandr
    Yermolenko <oleksandr.yermolenko@gmail.com>
 
    This file is part of MDTK, the Molecular Dynamics Toolkit.
@@ -497,8 +497,6 @@ Brenner::Brenner(ParamSet parSet):
 void
 Brenner::setupPotential1()
 {
-  PTRACE("Setup Brenner1");
-  
   Re_[C][C] = 1.315*Ao;
   Re_[H][H] = 0.74144*Ao;
   Re_[C][H] = 1.1199*Ao;
@@ -550,13 +548,13 @@ Brenner::setupPotential1()
   do_ = 2.5;
 
   G_HH_ = 4.0;
-}  
+
+  PRINT("Brenner1 interatomic potential configured.");
+}
 
 void
 Brenner::setupPotential2()
 {
-  PTRACE("Setup Brenner2");
-
   Re_[C][C] = 1.39*Ao;
   Re_[H][H] = 0.74144*Ao;
   Re_[C][H] = 1.1199*Ao;
@@ -608,77 +606,9 @@ Brenner::setupPotential2()
   do_ = 3.5;
 
   G_HH_ = 12.33;
-}  
 
-inline
-Float
-Brenner::HN_CC_num(Float a1, Float a2) const
-{
-  return funcH_CC(a1,a2);
-} 
-
-inline
-Float
-Brenner::HN_CC_dH_num(Float a1, Float a2) const
-{
-  return funcH_CC.dH(a1,a2);
-} 
-
-inline
-Float
-Brenner::HN_CC_dC_num(Float a1, Float a2) const
-{
-  return funcH_CC.dC(a1,a2);
-} 
-
-inline
-Float
-Brenner::HN_CH_num(Float a1, Float a2) const
-{
-  return funcH_CH(a1,a2);
-} 
-
-inline
-Float
-Brenner::HN_CH_dH_num(Float a1, Float a2) const
-{
-  return funcH_CH.dH(a1,a2);
-} 
-
-inline
-Float
-Brenner::HN_CH_dC_num(Float a1, Float a2) const
-{
-  return funcH_CH.dC(a1,a2);
-} 
-
-inline
-Float
-Brenner::FN_num(Float a1, Float a2, Float a3) const 
-{
-  return funcF(a1,a2,a3);
-} 
-
-inline
-Float
-Brenner::FN_dNconj_num(Float a1, Float a2, Float a3) const 
-{
-  return funcF.dk(a1,a2,a3);
-} 
-
-inline
-Float
-Brenner::FN_dNt_i_num(Float a1, Float a2, Float a3) const 
-{
-  return funcF.di(a1,a2,a3);
-} 
-
-inline
-Float
-Brenner::FN_dNt_j_num(Float a1, Float a2, Float a3) const 
-{
-  return funcF.dj(a1,a2,a3);
-} 
+  PRINT("Brenner2 interatomic potential configured.");
+}
 
 }
 
