@@ -2,8 +2,8 @@
    Implementation of the many-body interatomic potential for copper.
    See [G. Betz, W. Husinsky, Nucl. Instr. and Meth. B 102, 281 (1995)]
 
-   Copyright (C) 2006, 2007, 2008, 2009, 2012 Oleksandr Yermolenko
-   <oleksandr.yermolenko@gmail.com>
+   Copyright (C) 2006, 2007, 2008, 2009, 2012, 2013 Oleksandr
+   Yermolenko <oleksandr.yermolenko@gmail.com>
 
    This file is part of MDTK, the Molecular Dynamics Toolkit.
 
@@ -37,17 +37,17 @@ TightBinding::operator()(AtomsArray& gl)
     if (isHandled(atom_i))
     {
       Ei += F(atom_i);
-    }
 
-    for(size_t jj = 0; jj < NL(atom_i).size(); jj++)
-    {
-      Atom &atom_j = *(NL(atom_i)[jj]);
-      if (atom_i.globalIndex > atom_j.globalIndex) continue;
-      if (&atom_i != &atom_j)
+      for(size_t jj = 0; jj < NL(atom_i).size(); jj++)
       {
-        if (!probablyAreNeighbours(atom_i,atom_j)) continue;
-        AtomsPair ij(atom_i,atom_j,R(0,atom_i,atom_j),R(1,atom_i,atom_j));
-        Ei += Phi(ij);
+        Atom &atom_j = *(NL(atom_i)[jj]);
+        if (atom_i.globalIndex > atom_j.globalIndex) continue;
+        if (&atom_i != &atom_j)
+        {
+          if (!probablyAreNeighbours(atom_i,atom_j)) continue;
+          AtomsPair ij(atom_i,atom_j,R(0,atom_i,atom_j),R(1,atom_i,atom_j));
+          Ei += Phi(ij);
+        }
       }
     }
   }
@@ -174,8 +174,6 @@ TightBinding::TightBinding():
 void
 TightBinding::setupPotential()
 {
-  PTRACE("Setup TightBinding");
-
   alpha_ = 42.87/(10.0*Ao);
   beta_  = 18.00/(10.0*Ao);
   c_     = 12.17*eV;
@@ -186,6 +184,8 @@ TightBinding::setupPotential()
   BM_A = 22.565*1000.0*eV;
   BM_B = 50.88/(10.0*Ao);
   fillR_concat_();
+
+  PRINT("TightBinding interatomic potential configured.\n");
 }
 
 void
@@ -199,9 +199,6 @@ TightBinding::fillR_concat_()
   Float       x[2]; x[0] = 1.0*Ao; x[1] = 1.2*Ao;
   Float       v[2];
   Float    dvdx[2];
-//  Float    d2vdxdx[2];
-//  d2vdxdx[0] = 0;
-//  d2vdxdx[1] = 0;
 
   REQUIRE(x[1] < R_[0]);
 
@@ -230,7 +227,7 @@ TightBinding::fillR_concat_()
     dvdx[1] = DerVLongRange;
   }
 
-  spline = new Spline(x,v,dvdx/*,d2vdxdx*/);
+  spline = new Spline(x,v,dvdx);
 }
 
 }
