@@ -1,7 +1,7 @@
 /*
    The Born-Mayer interatomic potential implementation.
 
-   Copyright (C) 2004, 2005, 2009, 2012 Oleksandr Yermolenko
+   Copyright (C) 2004, 2005, 2009, 2012, 2013 Oleksandr Yermolenko
    <oleksandr.yermolenko@gmail.com>
 
    This file is part of MDTK, the Molecular Dynamics Toolkit.
@@ -75,8 +75,7 @@ for(size_t i = 0; i < gl.size(); i++)
 {
   Atom& atom = gl[i];
   AtomRefsContainer& nl = NL(atom);
-  Index j;
-  for(j = 0; j < nl.size(); j++)
+  for(size_t j = 0; j < nl.size(); j++)
   {
     Atom &atom_j = *(nl[j]);
     if (atom.globalIndex > atom_j.globalIndex) continue;
