@@ -1,8 +1,8 @@
 /*
    The ReleaseInfo class.
 
-   Copyright (C) 2004, 2009, 2010, 2011, 2012 Oleksandr Yermolenko
-   <oleksandr.yermolenko@gmail.com>
+   Copyright (C) 2004, 2009, 2010, 2011, 2012, 2013 Oleksandr
+   Yermolenko <oleksandr.yermolenko@gmail.com>
 
    This file is part of MDTK, the Molecular Dynamics Toolkit.
 
@@ -28,9 +28,9 @@ namespace mdtk
 ReleaseInfo release_info
   (
     "(MDTK)",
-    "0.7.0",
+    "0.8.0",
     "",
-    "2012 Oleksandr Yermolenko <oleksandr.yermolenko@gmail.com>",
+    "2013 Oleksandr Yermolenko <oleksandr.yermolenko@gmail.com>",
     "License GPLv3+: GNU GPL version 3 or later <http://gnu.org/licenses/gpl.html>\n\
 This is free software: you are free to change and redistribute it.\n\
 There is NO WARRANTY, to the extent permitted by law.\n"
